"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildModel = exports.BuildModelOptions = void 0;
// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License.
var yaml = require("js-yaml");
var Schema_1 = require("../Schema");
var SchemaClass_1 = require("../SchemaClass");
var glob = require("glob");
var defaultValue_1 = require("./defaultValue");
var fs = require('fs');
var path = require('path');
var BuildModelOptions = /** @class */ (function () {
    function BuildModelOptions() {
    }
    return BuildModelOptions;
}());
exports.BuildModelOptions = BuildModelOptions;
function buildModel(options) {
    var schemaFolder = options.schema;
    var toc = yaml.safeLoad(fs.readFileSync(options.toc));
    var items = [];
    var schema = Schema_1.Schema.fromFolder(schemaFolder);
    for (var index in toc) {
        var rootObj = toc[index];
        var root = {
            title: getObjectName(rootObj),
            children: [],
            schema: schema
        };
        for (var definitionIndex in rootObj[root.title]) {
            var name = rootObj[root.title][definitionIndex];
            var objSchema = schema.getType(name);
            if (objSchema === undefined) {
                console.warn("WARN: Unable to locate schema definition for " + name);
                continue;
            }
            var definition = {
                type: objSchema
            };
            definition.name = name;
            definition.version = defaultValue_1.defaultValue(objSchema.original.version, "1.0");
            definition.examples = [];
            definition.description = objSchema.description;
            if (objSchema instanceof SchemaClass_1.SchemaClass) {
                definition.properties = objSchema.getAllProperties();
            }
            if (options.examplesPath) {
                definition.examples = glob.sync("**/" + definition.name + ".json", { cwd: options.examplesPath, nocase: true, absolute: true });
            }
            if (definition.properties) {
                var properties = definition.properties;
                properties.forEach(function (property, properName) {
                    var anyProperty = property;
                    anyProperty.cardExamples = [];
                    if (options.examplesPath) {
                        var globPattern = "**/" + definition.name + "." + properName + ".json";
                        anyProperty.cardExamples = glob.sync(globPattern, { cwd: options.examplesPath, nocase: true, absolute: true });
                        //console.log(`Cwd: ${options.examplesPath} || Glob: ${globPattern} || Found ${anyProperty.cardExamples}`)
                    }
                });
            }
            root.children.push(definition);
        }
        items.push(root);
    }
    return items;
}
exports.buildModel = buildModel;
function getObjectName(obj) {
    for (var property in obj)
        return property;
}
//# sourceMappingURL=build-model.js.map